@@ -11,7 +11,7 @@ if TYPE_CHECKING:
 PRIMITIVE_TYPES: tuple[type[str], type[int], type[float], type[bool]] = (str, int, float, bool)
 
 
-def add_comparison_methods[T](attribute: str) -> Callable[[type[T]], type[T]]:
+def add_comparison_methods[T](attr: str) -> Callable[[type[T]], type[T]]:
     """Class decorator that adds rich comparison methods based on a specific attribute.
 
     This decorator adds __eq__, __ne__, __lt__, __gt__, __le__, __ge__, and __hash__ methods
@@ -20,7 +20,7 @@ def add_comparison_methods[T](attribute: str) -> Callable[[type[T]], type[T]]:
     that the attribute can be compared with.
 
     Args:
-        attribute: Name of the instance attribute to use for comparisons
+        attr: Name of the instance attribute to use for comparisons
 
     Returns:
         Class decorator function that adds comparison methods to a class
@@ -38,8 +38,8 @@ def add_comparison_methods[T](attribute: str) -> Callable[[type[T]], type[T]]:
             if isinstance(other, PRIMITIVE_TYPES):
                 return other
 
-            if hasattr(other, attribute):
-                return getattr(other, attribute)
+            if hasattr(other, attr):
+                return getattr(other, attr)
 
             return NotImplemented
 
@@ -48,46 +48,46 @@ def add_comparison_methods[T](attribute: str) -> Callable[[type[T]], type[T]]:
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) == other_val
+            return getattr(self, attr) == other_val
 
         def ne(self: object, other: Any) -> NotImplementedType | bool:
             """Not equal comparison method (__ne__)."""
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) != other_val
+            return getattr(self, attr) != other_val
 
         def lt(self: object, other: Any) -> NotImplementedType | bool:
             """Less than comparison method (__lt__)."""
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) < other_val
+            return getattr(self, attr) < other_val
 
         def gt(self: object, other: Any) -> NotImplementedType | bool:
             """Greater than comparison method (__gt__)."""
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) > other_val
+            return getattr(self, attr) > other_val
 
         def le(self: object, other: Any) -> NotImplementedType | bool:
             """Less than or equal comparison method (__le__)."""
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) <= other_val
+            return getattr(self, attr) <= other_val
 
         def ge(self: object, other: Any) -> NotImplementedType | bool:
             """Greater than or equal comparison method (__ge__)."""
             other_val: NotImplementedType | Any = extract_comparable_value(self, other)
             if other_val is NotImplemented:
                 return NotImplemented
-            return getattr(self, attribute) >= other_val
+            return getattr(self, attr) >= other_val
 
         def hash_method(self: object) -> int:
             """Generate hash based on the attribute used for equality."""
-            return hash(getattr(self, attribute))
+            return hash(getattr(self, attr))
 
         cls.__eq__ = eq
         cls.__ne__ = ne
