@@ -25,7 +25,7 @@ class FancyStack[T](SimpleStackCursor[T]):
         """
         self.states.push_state(name, self.index, self.stack)
 
-    def load_state(self, name: str):
+    def load_state(self, name: str) -> bool:
         """Load a saved state of the stack from the cursor by name.
 
         Args:
