@@ -6,6 +6,7 @@ from pydantic import BaseModel
 from pydantic.fields import FieldInfo
 
 from bear_dereth.datastore.columns import Columns
+from bear_dereth.models.helpers import extract_field_attrs
 
 
 class BaseSettingsModel(BaseModel):
@@ -31,13 +32,8 @@ class BaseSettingsModel(BaseModel):
         """Get the list of columns for the settings model."""
         columns: list[Columns] = []
         for field in cls.field_values():
-            if isinstance(field, FieldInfo) and hasattr(field, "annotation") and issubclass(field.annotation, Columns):  # type: ignore[attr-defined]
-                col: Columns = field.default
-                if col.type is None and hasattr(field, "annotation") and hasattr(field.annotation, "__args__"):  # type: ignore[attr-defined]
-                    args = getattr(field.annotation, "__args__", ())
-                    if args and len(args) == 1:
-                        col.type = args[0].__name__ if hasattr(args[0], "__name__") else str(args[0])  # type: ignore[attr-defined]
-                if not isinstance(col, Columns):
-                    continue
-                columns.append(col)
+            if isinstance(field, FieldInfo) and hasattr(field, "annotation"):  # type: ignore[attr-defined]
+                attrs: dict[str, Columns] = extract_field_attrs(cls, Columns)
+                for col in attrs.values():
+                    columns.append(col)
         return columns
