@@ -80,10 +80,11 @@ class FileInfo:
         from bear_dereth.platform_utils import OS, get_platform  # noqa: PLC0415
 
         platform: OS = get_platform()
-        if platform is OS.DARWIN:
-            return self.stat.st_birthtime if self.stat is not None else None
-        if platform is OS.WINDOWS:
-            return self.stat.st_ctime if self.stat is not None else None
+
+        if platform is OS.DARWIN and hasattr(self.stat, "st_birthtime"):
+            return getattr(self.stat, "st_birthtime", None)
+        if platform is OS.WINDOWS and self.stat is not None:
+            return self.stat.st_ctime
         return self.stat.st_mtime if self.stat is not None else None
 
     @property
