@@ -1,6 +1,5 @@
 """Tests for the dependency injection system."""
 
-from collections.abc import Generator
 import timeit
 from typing import TYPE_CHECKING, Annotated, Any, Union, get_type_hints
 from unittest.mock import Mock
@@ -17,28 +16,13 @@ from bear_dereth.di import (
     inject,
     parse_params,
 )
-from bear_dereth.exceptions import CannotFindTypeError, CannotInstantiateObjectError
-from bear_dereth.introspection import get_function_signature
+from bear_dereth.exceptions import CannotFindTypeError
+from bear_dereth.typing_tools import get_function_signature
 
 if TYPE_CHECKING:
     from inspect import Signature
 
 
-@pytest.fixture(autouse=True)
-def reset_di_global_state() -> Generator[None, Any]:
-    """Reset DI system global state before and after each test."""
-    # Import the real logger container that should be the default
-    from bear_dereth.logger.core.config import container as real_container  # noqa: PLC0415
-
-    original_container = getattr(Provide, "_container", None)
-
-    yield
-
-    # Always restore to the real logger container
-    # This ensures logger tests work after DI tests
-    Provide.set_container(real_container)
-
-
 class SimpleTestContainer(DeclarativeContainer):
     console: Console
 
@@ -420,8 +404,8 @@ class TestEdgeCases:
         assert isinstance(service, Provide)  # type: ignore[unreachable]
         assert service.service_name == "non_instantiable"
         assert service.result is not None  # If there is an error, we get the result object
-        assert isinstance(service.result.exception, CannotInstantiateObjectError)
-        assert "could not create service" in service.result.error.lower()
+        assert isinstance(service.result.exception, CannotFindTypeError)
+        assert "could not resolve type for service" in service.result.error.lower()
 
 
 class TestDifferentTypeAnnotations:
